#
# spec file for package librsb
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           librsb
%define lname	librsb0
%define rversion	1.2.0-rc7
Version:        1.2.0~rc7
Release:        lp151.2.12
Summary:        Shared memory parallel sparse matrix and sparse BLAS library
License:        LGPL-3.0+
Group:          Productivity/Scientific/Math
Url:            http://librsb.sf.net/

Source:         http://downloads.sf.net/%name/%name-%rversion.tar.gz
Patch1:         pun.diff
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
BuildRequires:  gsl-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
librsb is a library for sparse matrix computations featuring the
Recursive Sparse Blocks (RSB) matrix format. This format allows cache
efficient and multi-threaded (that is, shared memory parallel)
operations on large sparse matrices.

%package -n %lname
Summary:        Shared memory parallel sparse matrix and sparse BLAS library
Group:          System/Libraries

%description -n %lname
librsb is a library for sparse matrix computations featuring the
Recursive Sparse Blocks (RSB) matrix format. This format allows cache
efficient and multi-threaded (that is, shared memory parallel)
operations on large sparse matrices.

librsb implements the Sparse BLAS standard, as specified in the BLAS
Forum documents.

%package devel
Summary:        Development files for librsb, a Recursive Sparse Blocks matrix format lirary
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
librsb is a library for sparse matrix computations featuring the
Recursive Sparse Blocks (RSB) matrix format. This format allows cache
efficient and multi-threaded (that is, shared memory parallel)
operations on large sparse matrices.
 
This subpackage contains libraries and header files for developing
applications that want to make use of librsb.

%prep
%setup -qn librsb-%rversion
%patch -P 1 -p1

%build
%configure --docdir="%_docdir/%name" --disable-static CFLAGS="%optflags -Wno-unused"
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/librsb.so.0*

%files devel
%defattr(-,root,root)
%_includedir/*
%_bindir/rsbench
%_bindir/librsb-config
%_libdir/librsb.so
%_docdir/%name/
%doc COPYING

%changelog
* Tue Dec 26 2017 jengelh@inai.de
- Update to new upstream release 1.2.0~rc7
  * bugfix: rsb_spmv/rsb_spmm/BLAS_cusmv/BLAS_zusmv/BLAS_cusmm/
    BLAS_zusmm could compute wrong values on complex hermitian
    matrices if rhs imaginary part non null.
  * bugfix: complex conjugated transpose
    rsb_spsv/rsb_spsm/BLAS_cussv/BLAS_zussv/BLAS_cussm/BLAS_zussm
    could compute wrong values if rhs imaginary part non null.
  * bugfix: rsb_sppsp/rsb_mtx_clone would compute scaled
    conjugate of complex matrices wrong if alpha imaginary part
    non null.
  * might detect a forgotten rsb_lib_init() at first matrix
    allocation and return an error.
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 1.2.0~rc6
  * BLAS_zusget_element & co will behave one-based in Fortran.
  * rsb_sppsp was summing incorrectly certain non-overlapping
    sparse matrices.
  * rsb_file_mtx_save and rsb_file_vec_save's output use
    full-precision.
- Add pun.diff
* Thu Oct 20 2016 jengelh@inai.de
- Update to new upstream release 1.2.0~rc5
  * Fixed EPS rendering of matrices, e.g.
  `./rsbench --plot-matrix -aRzd -f matrix.mtx >matrix.eps`
- Drop shlib.diff (applied upstream)
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 1.2.0~rc3
  * Extension: if parameter flagsA of mtx_set_vals() has
  RSB_FLAG_DUPLICATES_SUM, then values will be summed up into the
  matrix.
  * Bugfix: rsb_mtx_get_nrm on symmetric matrices was buggy.
  * Bugfix: rsb_spsm potentially wrong in --enable-openmp and
  (nrhs>1). (ussm affected)
  * Bugfix: rsb_spsm wrong in --disable-openmp version and
  (nrhs>1). (ussm affected)
  * Bugfix: rsb_spsm used to scale only first rhs when (*alphap!=1
  and nrhs>1). (ussm affected)
  * Bugfix: rsb_spsm used to solve only first rhs when (y != x).
  (ussm not affected)
  * Bugfix: rsb_spmm used to scale only first rhs when (*betap!=1
  and nrhs>1). (usmm not affected)
  * Bugfix: rsb_tune_spmm/rsb_tune_spsm returned (false positive)
  error on ( mtxAp != NULL && mtxOpp != NULL ) rather than on (
  mtxAp != NULL && mtxOpp != NULL && *mtxOpp != NULL ).
  * Will use memset() on systems with no bzero() (e.g. mingw).
* Sun Jan 17 2016 jengelh@inai.de
- Initial package (versoin 1.2.0~rc2) for build.opensuse.org
